import Joi from '@hapi/joi';

import IdValidate from './id';

export default class ConditionValidate {
  private static condition = {
    number: Joi.string()
      .max(128),

    parameters: Joi.object()
      .pattern(/.*/, Joi.alternatives()
        .try(
          Joi.string().max(128),
          Joi.number(),
          Joi.boolean(),
          Joi.array()
        )
      )
  }

  static input (data, param) {
    if (param === 'new') {
      return Joi.object({
        sample_id: IdValidate.get().required(),
        number: this.condition.number.required(),
        parameters: this.condition.parameters.required(),
        treatment_template: IdValidate.get().required()
      }).validate(data);
    }
    else if (param === 'change') {
      return Joi.object({
        number: this.condition.number,
        parameters: this.condition.parameters
      }).validate(data);
    }
    else {
      return{error: 'No parameter specified!', value: {}};
    }
  }

  static output (data) {
    data = IdValidate.stringify(data);
    const {value, error} = Joi.object({
      _id: IdValidate.get(),
      sample_id: IdValidate.get(),
      number: this.condition.number,
      parameters: this.condition.parameters,
      treatment_template: IdValidate.get()
    }).validate(data, {stripUnknown: true});
    return error !== undefined? null : value;
  }
}